@@ -17,7 +17,7 @@ from collections import namedtuple
 import yaml
 
 from .proto_handlers import load_protocol_handler
-from .utils.connect import connect_to_database
+from .utils.connect import connect_to_database, dataframe_to_sql
 from .utils.dbconn import sql_enquote_id
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem
 from .utils.format_sniffer import find_url_extension, detect_format, looks_like_text_file
@@ -548,6 +548,12 @@ class DSLibrary(object):
         :param resource_name: Name of output resource where content should be stored.
         :param content:     Raw content for the data (various types), or a stream containing the data.
         :param append:      True to append, False to overwrite.
+
+        Optional arguments:
+            format              Specifies a file format like 'csv' or 'json'.
+            format_options      Options compatible with pandas.to_{format}()
+            sql_table           Causes dataframe-like data to be stored into a SQL table.
+            nosql_collection    Causes dataframe-like data to be stored into a NoSQL table (not yet implemented).
         """
         use_mlflow = self._mlflow_all
         # map resource name using supplied specs
@@ -558,19 +564,23 @@ class DSLibrary(object):
         format = kwargs.pop("format", None) or file_extension
         format_options = dict(kwargs.get("format_options") or {})
         # detect SQL target
-        if format_options.get("sql_table"):
-            # TODO formulate a bulk INSERT to write to the target table
-            # TODO if 'append' is False, we'll have to first drop everything from the table
-            # db_conn = self.get_sql_connection(resource_name)
-            raise NotImplementedError("SQL write of columnar data is not yet implemented")
-        if format_options.get("nosql_collection"):
+        if kwargs.get("sql_table"):
+            # write data to an SQL table
+            db_conn = self.get_sql_connection(resource_name, database=kwargs.get("database"))
+            content = _coerce_to_dataframe(content)
+            try:
+                table = kwargs.get("sql_table")
+                for sql, params in dataframe_to_sql(content, table_name=table, append=append):
+                    db_conn.cursor().execute(sql, params)
+            finally:
+                db_conn.close()
+            return
+        if kwargs.get("nosql_collection"):
             # TODO detect nosql (nosql_collection) and write data there
             raise NotImplementedError("NoSQL write of columnar data is not yet implemented")
         # we detect numpy arrays, series, etc., and save them as a dataframe with one column
         if isinstance(content, (pandas.Series, numpy.ndarray, pandas.Index)):
-            series = content
-            content = pandas.DataFrame()
-            content[resource_name] = series
+            content = _coerce_to_dataframe(content)
         # send (pandas) DataFrame as CSV/etc.
         df_format = format if format in PANDAS_WRITE_FORMATS else "csv"
         if hasattr(content, PANDAS_WRITE_FORMATS[df_format]):
@@ -987,6 +997,23 @@ LOCAL_SPECS_SCHEMA = {
 }
 
 
+def _coerce_to_dataframe(content):
+    """
+    Turn things into dataframes.
+    """
+    if hasattr(content, "columns") and hasattr(content, "itertuples"):
+        return content
+    elif hasattr(content, "__iter__"):
+        content = pandas.DataFrame(content)
+        if len(content.columns) and not isinstance(content.columns[0], str):
+            # numeric column names export ambiguously to CSV
+            # TODO align this convention with pandas methods which generate (maybe) "Col_1", etc.
+            content.columns = [f"col{n}" for n in range(1, len(content.columns)+1)]
+        return content
+    else:
+        raise NotImplementedError(f"cannot convert {type(content)} to dataframe")
+
+
 PANDAS_READ_FORMATS = {
     "csv": pandas.read_csv,
     # TODO should we use json_normalize() or read_json() here, or add a switch?
