@@ -11,6 +11,8 @@ FileFormatDescription = namedtuple("FileFormatDescription", "format read_args si
 
 # values that are unlikely to be header names, i.e. blank or numeric
 PTN_NOT_HEADER = re.compile(r'^([-+]?\s*(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?)?$')
+# a likely looking single-column CSV file - first line contains a non-delimited string-like value
+PTN_SINGLE_COL_CSV = re.compile(r'^(?!([0-9]|\.[0-9]|{|\[))' + r'[^\s,;|:]+[ \t]*\n.*')
 
 
 def detect_format(
@@ -119,13 +121,13 @@ def looks_like_csv(sample):
     :returns:  Separator or None.
     """
     if not sample:
-        return False
+        return
     if not isinstance(sample, str):
         try:
             sample = sample.decode("utf-8")
         except UnicodeDecodeError:
             # non-unicode >> assume not CSV
-            return False
+            return
     lines = sample.split("\n")[:10]
     for splitter, sep, threshold in ((re.compile(r"\t"), "\t", 2), (re.compile(r","), ",", 2), (re.compile(r"\s+"), "\\s+", 3)):
         n_cols = []
@@ -135,7 +137,8 @@ def looks_like_csv(sample):
         if min(n_cols) != max(n_cols) or n_cols[0] < threshold:
             continue
         return sep
-
+    if PTN_SINGLE_COL_CSV.match(sample):
+        return "\n"
 
 def looks_like_json(sample, size: int=None):
     """
@@ -154,7 +157,7 @@ def looks_like_json(sample, size: int=None):
     if not sample.startswith("{") and not sample.startswith("["):
         return False
     # JSON cannot contain non-ascii characters
-    if re.search(r'[^\x20-\x7F]', sample):
+    if re.search(r'[^\x20-\x7F\r\t\n]', sample):
         return False
     # if we know the size and our sample goes to the end we can check that as well
     if size and len(sample) == size:
