@@ -126,12 +126,12 @@ class TestFront(unittest.TestCase):
         # series
         dsl.write_resource("x", pandas.Series([1, 2, 3]))
         assert log[0][0] == "x"
-        self.assertEqual(log[0][1].getvalue(), 'x\n1\n2\n3\n')
+        self.assertEqual(log[0][1].getvalue(), 'col1\n1\n2\n3\n')
         log.clear()
         # numpy array
         dsl.write_resource("x", numpy.array([1, 2, 3]))
         assert log[0][0] == "x"
-        self.assertEqual(log[0][1].getvalue(), 'x\n1\n2\n3\n')
+        self.assertEqual(log[0][1].getvalue(), 'col1\n1\n2\n3\n')
         log.clear()
         # dataframe
         dsl.write_resource("x", pandas.DataFrame({"y": [1, 2, 3]}))
@@ -503,3 +503,36 @@ class TestFront(unittest.TestCase):
         df = MyInst().load_dataframe("x")
         assert "run_id" in df.columns
         assert "name" in df.columns
+
+    def test_write_resource_sql_table(self):
+        log = []
+        class MyInst(DSLibrary):
+            def get_sql_connection(self, resource_name: str, for_write: bool=False, database=None, **kwargs):
+                assert resource_name == "my_pg"
+                assert database == "db4"
+                class DbCursor(object):
+                    def execute(self, sql, params):
+                        log.append((sql, params))
+                    def __iter__(self):
+                        return iter([])
+                class DbConn(object):
+                    def cursor(self):
+                        return DbCursor()
+                    def close(self):
+                        pass
+                return DbConn()
+        # JSON data
+        MyInst().write_resource("my_pg", {"x": [1, 2, 3]}, append=False, sql_table="tbl1", database="db4")
+        self.assertEqual(log, [
+            ('DROP TABLE IF EXISTS tbl1', []),
+            ('CREATE TABLE IF NOT EXISTS tbl1 (x INTEGER)', []),
+            ('INSERT INTO tbl1 (x) VALUES (%s), (%s), (%s)', [1, 2, 3])
+        ])
+        log.clear()
+        # a series
+        MyInst().write_resource("my_pg", pandas.Series([1, 2, 3]), append=False, sql_table="tbl1", database="db4")
+        self.assertEqual(log, [
+            ('DROP TABLE IF EXISTS tbl1', []),
+            ('CREATE TABLE IF NOT EXISTS tbl1 (col1 INTEGER)', []),
+            ('INSERT INTO tbl1 (col1) VALUES (%s), (%s), (%s)', [1, 2, 3])
+        ])
